==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchSynthetics.md <==
# AmazonCloudWatchSynthetics


```text
aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchSynthetics
```

```text
include('aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchSynthetics')
```



| Illustration | AmazonCloudWatchSynthetics | AmazonCloudWatchSyntheticsCard | AmazonCloudWatchSyntheticsGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchSynthetics.png) | ![illustration for AmazonCloudWatchSynthetics](../../../aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchSynthetics.Local.png) | ![illustration for AmazonCloudWatchSyntheticsCard](../../../aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchSyntheticsCard.Local.png) | ![illustration for AmazonCloudWatchSyntheticsGroup](../../../aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchSyntheticsGroup.Local.png) |




## AmazonCloudWatchSynthetics

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchSynthetics
include('aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchSynthetics')

' renders the element
AmazonCloudWatchSynthetics('AmazonCloudWatchSynthetics', 'Amazon Cloud Watch Synthetics', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchSynthetics
include('aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchSynthetics')

' renders the element
AmazonCloudWatchSynthetics('AmazonCloudWatchSynthetics', 'Amazon Cloud Watch Synthetics', 'an optional tech label')
@enduml
```

## AmazonCloudWatchSyntheticsCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchSyntheticsCard
include('aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchSynthetics')

' renders the element
AmazonCloudWatchSyntheticsCard('AmazonCloudWatchSyntheticsCard', 'Amazon Cloud Watch Synthetics Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchSyntheticsCard
include('aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchSynthetics')

' renders the element
AmazonCloudWatchSyntheticsCard('AmazonCloudWatchSyntheticsCard', 'Amazon Cloud Watch Synthetics Card', 'an optional description')
@enduml
```

## AmazonCloudWatchSyntheticsGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchSyntheticsGroup
include('aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchSynthetics')

' renders the element
AmazonCloudWatchSyntheticsGroup('AmazonCloudWatchSyntheticsGroup', 'Amazon Cloud Watch Synthetics Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchSyntheticsGroup
include('aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchSynthetics')

' renders the element
AmazonCloudWatchSyntheticsGroup('AmazonCloudWatchSyntheticsGroup', 'Amazon Cloud Watch Synthetics Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchSynthetics.md <==
# AmazonCloudWatchSynthetics


```text
aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchSynthetics
```

```text
include('aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchSynthetics')
```



| Illustration | AmazonCloudWatchSynthetics | AmazonCloudWatchSyntheticsCard | AmazonCloudWatchSyntheticsGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchSynthetics.png) | ![illustration for AmazonCloudWatchSynthetics](../../../aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchSynthetics.Local.png) | ![illustration for AmazonCloudWatchSyntheticsCard](../../../aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchSyntheticsCard.Local.png) | ![illustration for AmazonCloudWatchSyntheticsGroup](../../../aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchSyntheticsGroup.Local.png) |




## AmazonCloudWatchSynthetics

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchSynthetics
include('aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchSynthetics')

' renders the element
AmazonCloudWatchSynthetics('AmazonCloudWatchSynthetics', 'Amazon Cloud Watch Synthetics', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchSynthetics
include('aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchSynthetics')

' renders the element
AmazonCloudWatchSynthetics('AmazonCloudWatchSynthetics', 'Amazon Cloud Watch Synthetics', 'an optional tech label')
@enduml
```

## AmazonCloudWatchSyntheticsCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchSyntheticsCard
include('aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchSynthetics')

' renders the element
AmazonCloudWatchSyntheticsCard('AmazonCloudWatchSyntheticsCard', 'Amazon Cloud Watch Synthetics Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchSyntheticsCard
include('aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchSynthetics')

' renders the element
AmazonCloudWatchSyntheticsCard('AmazonCloudWatchSyntheticsCard', 'Amazon Cloud Watch Synthetics Card', 'an optional description')
@enduml
```

## AmazonCloudWatchSyntheticsGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchSyntheticsGroup
include('aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchSynthetics')

' renders the element
AmazonCloudWatchSyntheticsGroup('AmazonCloudWatchSyntheticsGroup', 'Amazon Cloud Watch Synthetics Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonCloudWatchSyntheticsGroup
include('aws-q3-2021/Resource/ManagementGovernance/AmazonCloudWatchSynthetics')

' renders the element
AmazonCloudWatchSyntheticsGroup('AmazonCloudWatchSyntheticsGroup', 'Amazon Cloud Watch Synthetics Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
